# LiveShot rendering
Card (i.e. a single lane) and range rendering is primarily performed by the two
classes `MegalinkCardRenderer` and `MegalinkRangeRenderer`. As these names
suggest, they will render the targets in a style similar to that of MLView
supplied by Megalink. A similar way to render targets in a style similar to
that of KTS (Kongsberg Target Systems) is not currently implemented, but might
appear in the future.

## Overview
`MegalinkCardRenderer` and `MegalinkRangeRenderer` work in the same way. In
short what you need to do in order to use either of them is:

1. Create a new instance of the renderer  
    `var renderer = new MegalinkCardRenderer();`
2. Supply a canvas rendering context  
    `renderer.setContext(someCanvas.getContext('2d'));`
3. Set the rectangle to draw within  
    `renderer.setRect({x: 0, y: 0, width: 100, height: 100});`
4. Supply the data to draw  
    `renderer.setCard(someCard);`
5. Render  
    `renderer.render();`

`MegalinkRangeRenderer` works the same way (except that the supplied data is
different).

## `MegalinkRangeRenderer`
All methods return pointer to the renderer for convenience.

* **setContext**(< _CanvasRenderingContext2D_ >context) - ( _Renderer_ )
* **setRect**(< _object_ >rect) - ( _Renderer_ )  
    `rect` describes the rectangle to render within, should contain the
    following properties:
        * < _number_ >`x`
        * < _number_ >`y`
        * < _number_ >`width`
        * < _number_ >`height`
* **setRange**(< _Range_ >range) - ( _Renderer_ )  
    `range` should be as described in [data format](format.md#the-range-object)
* **setCards**(< _iterable_ >cards) - ( _Renderer_ )  
    `cards` should be an iterable collection (i.e. `array` or `object`) with
    `Card` elements as described in [data format](format.md#the-card-object)
* **render**() - ( _Renderer_ )  
    Renders into `context`, within the rectangle defined by `x`, `y`,
    `width` and `height`, scaled to `scale`. Returns pointer to renderer for
    convenience.

`MegalinkRangeRenderer` extends [Renderer](internals.md#renderer) which also
contains some other convenience methods.

## `MegalinkCardRenderer`
All methods return pointer to the renderer for convenience.

* **setContext**(< _CanvasRenderingContext2D_ >context) - ( _Renderer_ )
* **setRect**(< _object_ >rect) - ( _Renderer_ )  
    `rect` describes the rectangle to render within, should contain the
    following properties:
        * < _number_ >`x`
        * < _number_ >`y`
        * < _number_ >`width`
        * < _number_ >`height`
* **setCard**(< _Card_ >card) - ( _Renderer_ )  
    `card` should be as described in [data format](format.md#the-card-object)
* **render**() - ( _Renderer_ )  
    Renders into `context`, within the rectangle defined by `x`, `y`,
    `width` and `height`, scaled to `scale`. Returns pointer to renderer for
    convenience.

`MegalinkCardRenderer` extends [Renderer](internals.md#renderer) which also
contains some other convenience methods.
