var inherits = require('inherits');

var MegalinkCardRenderer = require('./MegalinkCardRenderer');
var RangeRenderer = require('../RangeRenderer');
var utils = require('./utils');

// --- Constants ---
var HEADER_MARGIN = 8;

function MegalinkRangeRenderer() {
    RangeRenderer.prototype.constructor.apply(this);
}

module.exports = MegalinkRangeRenderer;
inherits(MegalinkRangeRenderer, RangeRenderer);

// --- Internal API ---
MegalinkRangeRenderer.prototype.initialize = function () {
    RangeRenderer.prototype.initialize.apply(this);

    this.style.frontColor = 'rgb(0, 0, 0)';
};

MegalinkRangeRenderer.prototype.CardRenderer = MegalinkCardRenderer;

MegalinkRangeRenderer.prototype.draw = function () {
    RangeRenderer.prototype.draw.apply(this);

    this.drawHeader();
};

MegalinkRangeRenderer.prototype.drawHeader = function () {
    var ctx = this.context;
    var rect = this.getHeaderRect();

    if (rect.height === 0) {
        return;
    }

    ctx.clearRect(rect.x, rect.y, rect.width, rect.height);

    this.drawHost(rect);
    this.drawRangeRelay(rect);
    this.drawLogo(rect);
};

MegalinkRangeRenderer.prototype.drawHost = function (rect) {
    var ctx = this.context;
    var rect = MegalinkRangeRenderer.getHostRect(rect);
    var host = this.range.host;

    ctx.fillStyle = this.style.frontColor;
    utils.setFont(ctx, host, rect.width, rect.height);
    ctx.textAlign = 'center';
    ctx.textBaseline = 'middle';
    ctx.fillText(host, rect.x + rect.width/2, rect.y + rect.height/2);
    ctx.textAlign = 'left';
    ctx.textBaseline = 'alphabetic';
};

MegalinkRangeRenderer.prototype.drawRangeRelay = function (rect) {
    var ctx = this.context;
    var rangeRelay = this.range.name + ' - Lag nr ' + this.range.relay;
    var rangeRelayRect = MegalinkRangeRenderer.getRangeRelayRect(rect);

    ctx.fillStyle = this.style.frontColor;
    utils.setFont(ctx, rangeRelay, rangeRelayRect.width, rangeRelayRect.height);

    ctx.textBaseline = 'middle';
    ctx.fillText(rangeRelay, rangeRelayRect.x, rangeRelayRect.y + rangeRelayRect.height/2);
    ctx.textBaseline = 'alphabetic';
};

MegalinkRangeRenderer.prototype.drawLogo = function (rect) {
    var ctx = this.context;

    if (!this.logo || this.logo.width == 0) {
        this.logo = new Image();
        this.logo.src = 'images/mllogo.png';

        var self = this;
        this.logo.onload = function () {
            self.drawLogo(rect);
        };

        return;
    }

    var maxRect = MegalinkRangeRenderer.getLogoMaxRect(rect);

    var maxWidth = maxRect.width*0.9;
    var maxHeight = maxRect.height*0.9;
    var width = this.logo.width;
    var height = this.logo.height;

    var logoTooLarge = width > maxWidth || height > maxHeight;

    if (logoTooLarge) {
        var ratio = width / height;

        if (maxWidth < maxHeight*ratio) {
            width = maxWidth;
            height = maxWidth / ratio;
        } else {
            width = maxHeight * ratio;
            height = maxHeight;
        }
    }

    var left = rect.x + rect.width - HEADER_MARGIN - width;
    var top = rect.y + rect.height/2 - height/2;

    ctx.drawImage(this.logo, left, top, width, height);
};

// --- Rect utils ---
MegalinkRangeRenderer.prototype.getCardsRect = function (rect) {
    return MegalinkRangeRenderer.getCardsRect(this.rect);
};

MegalinkRangeRenderer.prototype.getHeaderRect = function () {
    return MegalinkRangeRenderer.getHeaderRect(this.rect);
};

MegalinkRangeRenderer.getCardsRect = function (rect) {
    return {
        x: 0,
        y: Math.floor(0.09*rect.height),
        width: rect.width,
        height: Math.ceil(0.91*rect.height)
    };
};

MegalinkRangeRenderer.getHeaderRect = function (rect) {
    return {
        x: 0,
        y: 0,
        width: rect.width,
        height: Math.floor(0.09*rect.height)
    };
};

MegalinkRangeRenderer.getHostRect = function (rect) {
    return {
        x:rect.x + rect.width/4 + 2*HEADER_MARGIN,
        y:rect.y + 2*HEADER_MARGIN,
        width:rect.width/2 - 4*HEADER_MARGIN,
        height:rect.height - 4*HEADER_MARGIN
    };
};

MegalinkRangeRenderer.getRangeRelayRect = function (rect) {
    return {
        x:rect.x + 3*HEADER_MARGIN,
        y:rect.y + HEADER_MARGIN,
        width:rect.width/5,
        height:rect.height - 2*HEADER_MARGIN
    };
};

MegalinkRangeRenderer.getLogoMaxRect = function (rect) {
    return {
        x:rect.x + 5*rect.width/8,
        y:rect.y + HEADER_MARGIN,
        width:rect.width/4,
        height:rect.height - 2*HEADER_MARGIN
    };
};
