var RingTargetScaler = require('../scaler/RingTargetScaler');
var RingTargetRenderer = require('../renderer/RingTargetRenderer');

var ShotRenderer = require('../renderer/ShotRenderer');

var ISSFSilhouetteFinalPistolTargetScaler = require('../scaler/ISSFSilhouetteFinalPistolTargetScaler');
var ISSFSilhouetteFinalPistolTargetRenderer = require('../renderer/ISSFSilhouetteFinalPistolTargetRenderer');
var ISSFSilhouetteFinalPistolShotRenderer = require('../renderer/ISSFSilhouetteFinalPistolShotRenderer');

var targets =  {
    'NO_DFS_100M':require('./dfs/NO_DFS_100M'),
    'NO_DFS_200M':require('./dfs/NO_DFS_200M'),
    'NO_DFS_300M':require('./dfs/NO_DFS_300M'),
    'NO_DFS_15M':require('./dfs/NO_DFS_15M'),
    'NO_NSF_RIFLE_200M':require('./nsf/NO_NSF_RIFLE_200M'),
    'NO_NSF_RIFLE_15M':require('./nsf/NO_NSF_RIFLE_15M'),
    'DK_DDS_RIFLE_15M_M84':require('./dds/DK_DDS_RIFLE_15M_M84'),
    'DK_DDS_RIFLE_15M_M96':require('./dds/DK_DDS_RIFLE_15M_M96'),
    'DK_DDS_RIFLE_50M_M90':require('./dds/DK_DDS_RIFLE_50M_M90'),
    'DK_DDS_RIFLE_200M':require('./dds/DK_DDS_RIFLE_200M'),
    'DK_DDS_PISTOL_15M_M2000':require('./dds/DK_DDS_PISTOL_15M_M2000'),
    'DK_DSU_RIFLE_15M':require('./dsu/DK_DSU_RIFLE_15M'),
    'INT_ISSF_PISTOL_10M':require('./issf/INT_ISSF_PISTOL_10M'),
    'INT_ISSF_RIFLE_10M':require('./issf/INT_ISSF_RIFLE_10M'),
    'INT_ISSF_RIFLE_50M':require('./issf/INT_ISSF_RIFLE_50M'),
    'INT_ISSF_RIFLE_300M':require('./issf/INT_ISSF_RIFLE_300M'),
    'INT_ISSF_PRECISION_PISTOL':require('./issf/INT_ISSF_PRECISION_PISTOL'),
    'INT_ISSF_SILHOUETTE_PISTOL':require('./issf/INT_ISSF_SILHOUETTE_PISTOL'),
    'INT_ISSF_SILHOUETTE_FINAL_PISTOL':require('./issf/INT_ISSF_SILHOUETTE_FINAL_PISTOL'),
    'INT_ISSF_SILHOUETTE_FINAL_WOMEN_PISTOL':require('./issf/INT_ISSF_SILHOUETTE_FINAL_WOMEN_PISTOL'),
    'UNKNOWN':require('./dfs/NO_DFS_100M')
};

function getTarget(targetID) {
    return targets[targetID];
}

function getScaler(targetID) {
    switch (targetID) {
        case 'NO_DFS_100M':
        case 'NO_DFS_200M':
        case 'NO_DFS_300M':
        case 'NO_DFS_15M':
        case 'NO_NSF_RIFLE_200M':
        case 'NO_NSF_RIFLE_15M':
        case 'DK_DDS_RIFLE_15M_M84':
        case 'DK_DDS_RIFLE_15M_M96':
        case 'DK_DDS_RIFLE_50M_M90':
        case 'DK_DDS_RIFLE_200M':
        case 'DK_DDS_PISTOL_15M_M2000':
        case 'DK_DSU_RIFLE_15M':
        case 'INT_ISSF_PISTOL_10M':
        case 'INT_ISSF_RIFLE_10M':
        case 'INT_ISSF_RIFLE_50M':
        case 'INT_ISSF_RIFLE_300M':
        case 'INT_ISSF_PRECISION_PISTOL':
        case 'INT_ISSF_SILHOUETTE_PISTOL':
        case 'UNKNOWN':
            return new RingTargetScaler()
                .setTarget(getTarget(targetID));
        case 'INT_ISSF_SILHOUETTE_FINAL_PISTOL':
        case 'INT_ISSF_SILHOUETTE_FINAL_WOMEN_PISTOL':
            return new ISSFSilhouetteFinalPistolTargetScaler();
    }
}

function getTargetRenderer(targetID) {
    switch (targetID) {
        case 'NO_DFS_100M':
        case 'NO_DFS_200M':
        case 'NO_DFS_300M':
        case 'NO_DFS_15M':
        case 'NO_NSF_RIFLE_200M':
        case 'NO_NSF_RIFLE_15M':
        case 'DK_DDS_RIFLE_15M_M84':
        case 'DK_DDS_RIFLE_15M_M96':
        case 'DK_DDS_RIFLE_50M_M90':
        case 'DK_DDS_RIFLE_200M':
        case 'DK_DDS_PISTOL_15M_M2000':
        case 'DK_DSU_RIFLE_15M':
        case 'INT_ISSF_PISTOL_10M':
        case 'INT_ISSF_RIFLE_10M':
        case 'INT_ISSF_RIFLE_50M':
        case 'INT_ISSF_RIFLE_300M':
        case 'INT_ISSF_PRECISION_PISTOL':
        case 'INT_ISSF_SILHOUETTE_PISTOL':
        case 'UNKNOWN':
            return new RingTargetRenderer()
                .setTarget(getTarget(targetID));
        case 'INT_ISSF_SILHOUETTE_FINAL_PISTOL':
        case 'INT_ISSF_SILHOUETTE_FINAL_WOMEN_PISTOL':
            return new ISSFSilhouetteFinalPistolTargetRenderer()
                .setTarget(getTarget(targetID));
    }
}

function getShotRenderer(targetID) {
    switch (targetID) {
        case 'NO_DFS_100M':
        case 'NO_DFS_200M':
        case 'NO_DFS_300M':
        case 'NO_DFS_15M':
        case 'NO_NSF_RIFLE_200M':
        case 'NO_NSF_RIFLE_15M':
        case 'DK_DDS_RIFLE_15M_M84':
        case 'DK_DDS_RIFLE_15M_M96':
        case 'DK_DDS_RIFLE_50M_M90':
        case 'DK_DDS_RIFLE_200M':
        case 'DK_DDS_PISTOL_15M_M2000':
        case 'DK_DSU_RIFLE_15M':
        case 'INT_ISSF_PISTOL_10M':
        case 'INT_ISSF_RIFLE_10M':
        case 'INT_ISSF_RIFLE_50M':
        case 'INT_ISSF_RIFLE_300M':
        case 'INT_ISSF_PRECISION_PISTOL':
        case 'INT_ISSF_SILHOUETTE_PISTOL':
        case 'UNKNOWN':
            return new ShotRenderer();
        case 'INT_ISSF_SILHOUETTE_FINAL_PISTOL':
        case 'INT_ISSF_SILHOUETTE_FINAL_WOMEN_PISTOL':
            return new ISSFSilhouetteFinalPistolShotRenderer();
    }
}

module.exports = {
    getScaler:getScaler,
    getTargetRenderer:getTargetRenderer,
    getShotRenderer:getShotRenderer
};

for (var targetID in targets) {
    module.exports[targetID] = targets[targetID];
}
